@@ -35,12 +35,11 @@ cleanupLatex <- function(x) {
   }
 }
 
-#' @importFrom utils as.personList
 ArrangeAuthors <- function(x) {
   rx <- "(?i)[[:space:]]+and[[:space:]]+"
   x <- gsub("[[:space:]]{2,}", " ", x, useBytes = TRUE)
   authors <- lapply(strsplit(x, rx, perl = TRUE)[[1]], ArrangeSingleAuthor)
-  as.personList(authors)
+  do.call("c", authors)
 }
 
 ArrangeSingleAuthor <- function(y) {
@@ -253,7 +252,7 @@ do_read_bib <- function(file, encoding = "unknown", srcfile) {
       string_line <- lines[seq(init, end)]
       # Guess lines outside of the entry
 
-      guess_eostring <- max(grep("\\}$", string_line))
+      guess_eostring <- max(grep("\\}\\s*$", string_line))
 
       string_line <- string_line[seq(1, guess_eostring)]
 
